Mergeable

Trait Mergeable 

pub trait Mergeable: Copy {
    // Required methods
    fn could_be_equal(&self, other: &Self) -> bool;
    fn union(&self, other: &Self) -> Self;
}
A value that can be tested for approximate equality against another of the same type and combined into the smallest value definitely containing both — the building block DisjointSet merges on.

Required Methods

fn could_be_equal(&self, other: &Self) -> bool

fn union(&self, other: &Self) -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<A: Mergeable, B: Mergeable> Mergeable for (A, B)

Source

fn could_be_equal(&self, other: &Self) -> bool

Source

fn union(&self, other: &Self) -> Self

Implementors

Source

impl<S: Scalar, const N: usize> Mergeable for Vector<S, N>

Source

impl<S: Scalar> Mergeable for S